@@ -8,8 +8,7 @@ describe 'swift::proxy::ceilometer' do
      }'
   end
 
-  shared_examples 'swift-proxy-ceilometer' do
-
+  shared_examples 'swift::proxy::ceilometer' do
     describe "when using default parameters" do
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/paste.filter_factory').with_value('ceilometermiddleware.swift:filter_factory') }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/url').with_value('rabbit://guest:guest@127.0.0.1:5672//') }
@@ -32,7 +31,7 @@ describe 'swift::proxy::ceilometer' do
           :nonblocking_notify  => true,
           :ignore_projects     => ['services'],
 	  :auth_uri            => 'http://127.0.0.1:5000',
-	  :auth_url            => 'http://127.0.0.1:35357',
+	  :auth_url            => 'http://127.0.0.1:5000',
 	  :auth_type           => 'password',
 	  :project_domain_name => 'Default',
 	  :user_domain_name    => 'Default',
@@ -52,7 +51,7 @@ describe 'swift::proxy::ceilometer' do
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/nonblocking_notify').with_value('true') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/ignore_projects').with_value(['services']) }
 	it { is_expected.to contain_swift_proxy_config('filter:ceilometer/auth_uri').with_value('http://127.0.0.1:5000') }
-	it { is_expected.to contain_swift_proxy_config('filter:ceilometer/auth_url').with_value('http://127.0.0.1:35357') }
+	it { is_expected.to contain_swift_proxy_config('filter:ceilometer/auth_url').with_value('http://127.0.0.1:5000') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/auth_type').with_value('password') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/project_domain_name').with_value('Default') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/user_domain_name').with_value('Default') }
@@ -122,7 +121,7 @@ describe 'swift::proxy::ceilometer' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
-      it_behaves_like 'swift-proxy-ceilometer'
+      it_behaves_like 'swift::proxy::ceilometer'
     end
   end
 
